@@ -6,8 +6,7 @@
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
-#ifndef KALARM_COMPATIBILITY_ATTRIBUTE_H
-#define KALARM_COMPATIBILITY_ATTRIBUTE_H
+#pragma once
 
 #include "kalarmcal_export.h"
 
@@ -86,6 +85,5 @@ private:
 
 } // namespace KAlarmCal
 
-#endif // KALARM_COMPATIBILITY_ATTRIBUTE_H
 
 // vim: et sw=4:
