@@ -2,29 +2,15 @@
  *  repetition.h  -  represents a sub-repetition: interval and count
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2009-2012,2018 by David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2009-2012, 2018 David Jarvie <djarvie@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published
- *  by the Free Software Foundation; either version 2 of the License, or (at
- *  your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KALARM_REPETITION_H
-#define KALARM_REPETITION_H
+#pragma once
 
 #include "kalarmcal_export.h"
-#include <kcalcore/duration.h>
+#include <KCalendarCore/Duration>
 
 namespace KAlarmCal
 {
@@ -51,7 +37,7 @@ public:
     /** Constructor.
      *  Initialises with the specified @p interval and @p count.
      */
-    Repetition(const KCalCore::Duration &interval, int count);
+    Repetition(const KCalendarCore::Duration &interval, int count);
 
     Repetition(const Repetition &other);
 
@@ -60,12 +46,12 @@ public:
     Repetition &operator=(const Repetition &other);
 
     /** Initialises the instance with the specified @p interval and @p count. */
-    void set(const KCalCore::Duration &interval, int count);
+    void set(const KCalendarCore::Duration &interval, int count);
     /** Sets the @p interval. The repetition count is unchanged unless
      *  The repetition count is set to zero if @p interval is zero; otherwise
      *  the repetition count is unchanged.
      */
-    void set(const KCalCore::Duration &interval);
+    void set(const KCalendarCore::Duration &interval);
 
     /** Returns whether a repetition is defined.
      *  @return true if a repetition is defined, false if not.
@@ -90,15 +76,15 @@ public:
     int count() const;
 
     /** Return the interval between repetitions. */
-    KCalCore::Duration interval() const;
+    KCalendarCore::Duration interval() const;
 
     /** Return the overall duration of the repetition. */
-    KCalCore::Duration duration() const;
+    KCalendarCore::Duration duration() const;
 
     /** Return the overall duration of a specified number of repetitions.
      *  @param count the number of repetitions to find the duration of.
      */
-    KCalCore::Duration duration(int count) const;
+    KCalendarCore::Duration duration(int count) const;
 
     /** Check whether the repetition interval is in terms of days (as opposed to minutes). */
     bool isDaily() const;
@@ -137,6 +123,5 @@ private:
 
 } // namespace KAlarmCal
 
-#endif // KALARM_REPETITION_H
 
 // vim: et sw=4:
